effectBias: Compute bias for each effect size based on estimated weight function
Description
Based on the estimated weight function an explicit formula for the bias of each initial effect estimate can be derived,
see Rufibach (2011). This function implements computation of this bias and is called by DearBegg and DearBeggMonotone.
Usage
effectBias(y, u, w, theta, eta)
Value
A list consisting of the following elements:
dat
Matrix with columns \(y\), \(u\), \(y\), \(p\), bias, \(y\) - bias, bias / \(y\),
where the rows are provided in decreasing order of \(p\)-values.
Arguments
- y
Normally distributed effect sizes.
- u
Associated standard errors.
- w
Vector of estimated weights as computed by either DearBegg or DearBeggMonotone.
- theta
Effect size estimate.
- eta
Standard error of effect size estimate.
References
Rufibach, K. (2011).
Selection Models with Monotone Weight Functions in Meta-Analysis.
Biom. J., 53(4), 689--704.
Examples
Run this code# For an illustration see the help file for the function DearBegg().
Run the code above in your browser using DataLab